@@ -7,7 +7,7 @@ use FFI::Platypus;
 use constant _is_win32 => $^O =~ /^(MSWin32|cygwin|msys2?)$/ && FFI::Platypus->abis->{stdcall};
 
 # ABSTRACT: Perl Foreign Function Interface based on libffi
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 our $ffi = FFI::Platypus->new;
 $ffi->lib(undef);
@@ -52,10 +52,11 @@ sub _ffi
 
 sub call
 {
-  my($addr, $signature, @args) = @_;
+  my $addr = shift;
+  my $signature = shift;
   my $ffi = _ffi($signature);
   my($ret_type, @args_types) = map { $typemap{$_} } split //, $signature;
-  $ffi->function($addr => \@args_types => $ret_type)->call(@args);
+  $ffi->function($addr => \@args_types => $ret_type)->call(@_);
 }
 
 sub callback
@@ -90,7 +91,7 @@ FFI - Perl Foreign Function Interface based on libffi
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
